#ifndef KXSTATUSMESSAGEDIALOGIMPL_H
#define KXSTATUSMESSAGEDIALOGIMPL_H
#include "kxstatusmessagedialog.h"
#include <v2_codes.h>

class kxStatusMessageDialogImpl : public kxStatusMessageDialog
{ 
    Q_OBJECT

public:
    kxStatusMessageDialogImpl( UIN, QString , QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
    kxStatusMessageDialogImpl( UIN, int,  QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
    ~kxStatusMessageDialogImpl();
    
    UIN uin;
    bool modalDialog;
    int status;
    bool ok;
    
public slots:
  virtual void hide();
  void SlotCancelButton();  
  void SlotOkButton();

};

#endif // KXSTATUSMESSAGEDIALOGIMPL_H
